# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`singularity`](#singularity): Manage Singularity

#### Private Classes

* `singularity::config`: Private class
* `singularity::install::package`: Private class
* `singularity::install::source`: Private class

### Defined types

* [`singularity::plugin`](#singularityplugin): Manage Singularity plugin

## Classes

### <a name="singularity"></a>`singularity`

Manage Singularity

#### Examples

##### 

```puppet
include ::singularity
```

#### Parameters

The following parameters are available in the `singularity` class:

* [`install_method`](#install_method)
* [`package_ensure`](#package_ensure)
* [`package_name`](#package_name)
* [`manage_epel`](#manage_epel)
* [`version`](#version)
* [`source_dependencies`](#source_dependencies)
* [`manage_go`](#manage_go)
* [`rebuild_on_go`](#rebuild_on_go)
* [`source_base_dir`](#source_base_dir)
* [`source_mconfig_path`](#source_mconfig_path)
* [`build_flags`](#build_flags)
* [`build_env`](#build_env)
* [`prefix`](#prefix)
* [`localstatedir`](#localstatedir)
* [`sysconfdir`](#sysconfdir)
* [`source_exec_path`](#source_exec_path)
* [`plugins`](#plugins)
* [`config_path`](#config_path)
* [`config_template`](#config_template)
* [`allow_setuid`](#allow_setuid)
* [`max_loop_devices`](#max_loop_devices)
* [`allow_pid_ns`](#allow_pid_ns)
* [`config_passwd`](#config_passwd)
* [`config_group`](#config_group)
* [`config_resolv_conf`](#config_resolv_conf)
* [`mount_proc`](#mount_proc)
* [`mount_sys`](#mount_sys)
* [`mount_dev`](#mount_dev)
* [`mount_devpts`](#mount_devpts)
* [`mount_home`](#mount_home)
* [`mount_tmp`](#mount_tmp)
* [`mount_hostfs`](#mount_hostfs)
* [`bind_paths`](#bind_paths)
* [`user_bind_control`](#user_bind_control)
* [`enable_fusemount`](#enable_fusemount)
* [`enable_overlay`](#enable_overlay)
* [`enable_underlay`](#enable_underlay)
* [`mount_slave`](#mount_slave)
* [`sessiondir_max_size`](#sessiondir_max_size)
* [`limit_container_owners`](#limit_container_owners)
* [`limit_container_groups`](#limit_container_groups)
* [`limit_container_paths`](#limit_container_paths)
* [`allow_containers`](#allow_containers)
* [`allow_net_users`](#allow_net_users)
* [`allow_net_groups`](#allow_net_groups)
* [`allow_net_networks`](#allow_net_networks)
* [`always_use_nv`](#always_use_nv)
* [`always_use_rocm`](#always_use_rocm)
* [`root_default_capabilities`](#root_default_capabilities)
* [`memory_fs_type`](#memory_fs_type)
* [`cni_configuration_path`](#cni_configuration_path)
* [`cni_plugin_path`](#cni_plugin_path)
* [`mksquashfs_path`](#mksquashfs_path)
* [`mksquashfs_procs`](#mksquashfs_procs)
* [`mksquashfs_mem`](#mksquashfs_mem)
* [`cryptsetup_path`](#cryptsetup_path)
* [`shared_loop_devices`](#shared_loop_devices)
* [`image_driver`](#image_driver)
* [`namespace_users`](#namespace_users)
* [`namespace_begin_id`](#namespace_begin_id)
* [`namespace_id_range`](#namespace_id_range)
* [`subid_template`](#subid_template)

##### <a name="install_method"></a>`install_method`

Data type: `Enum['package','source']`

Sets how Singularity will be installed

Default value: `'package'`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Package ensure property
Only used when install_method=package

Default value: `'present'`

##### <a name="package_name"></a>`package_name`

Data type: `String`

Singularity package name
Only used when install_method=package

Default value: `'singularity'`

##### <a name="manage_epel"></a>`manage_epel`

Data type: `Boolean`

Determines if EPEL repo should be managed
Only used when install_method=package on RedHat based systems

Default value: ``true``

##### <a name="version"></a>`version`

Data type: `String`

Version of Singularity to install
Only used when install_method=source

Default value: `'3.7.4'`

##### <a name="source_dependencies"></a>`source_dependencies`

Data type: `Array`

Packages needed to build from source
Only used when install_method=source

Default value: `[]`

##### <a name="manage_go"></a>`manage_go`

Data type: `Boolean`

Sets if golang module should be included
Only used when install_method=source

Default value: ``true``

##### <a name="rebuild_on_go"></a>`rebuild_on_go`

Data type: `Boolean`

Sets if Singularity should be rebuilt on updates to Go via golang module
Only used when install_method=source and manage_go=true

Default value: ``true``

##### <a name="source_base_dir"></a>`source_base_dir`

Data type: `Stdlib::Absolutepath`

Base directory of where Singularity source will be extracted
Only used when install_method=source

Default value: `'/opt'`

##### <a name="source_mconfig_path"></a>`source_mconfig_path`

Data type: `Stdlib::Absolutepath`

Path to source install mconfig script

Default value: `'/usr/local/sbin/singularity-mconfig.sh'`

##### <a name="build_flags"></a>`build_flags`

Data type: `Hash`

Build flags to pass to mconfig when building Singularity
Only used when install_method=source

Default value: `{}`

##### <a name="build_env"></a>`build_env`

Data type: `Hash`

Environment variables to use when building from source
Only used when install_method=source

Default value: `{}`

##### <a name="prefix"></a>`prefix`

Data type: `Stdlib::Absolutepath`

The --prefix value when building from source
Only used when install_method=source

Default value: `'/usr'`

##### <a name="localstatedir"></a>`localstatedir`

Data type: `Stdlib::Absolutepath`

The --localstatedir value when building from source
Only used when install_method=source

Default value: `'/var'`

##### <a name="sysconfdir"></a>`sysconfdir`

Data type: `Stdlib::Absolutepath`

The --sysconfdir value when building from source
Only used when install_method=source

Default value: `'/etc'`

##### <a name="source_exec_path"></a>`source_exec_path`

Data type: `String`

Set PATH when building from source
Only used when install_method=source

Default value: `'/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin'`

##### <a name="plugins"></a>`plugins`

Data type: `Hash`

Hash to define singularity::plugin resources

Default value: `{}`

##### <a name="config_path"></a>`config_path`

Data type: `Stdlib::Absolutepath`

Path to singularity.conf

Default value: `'/etc/singularity/singularity.conf'`

##### <a name="config_template"></a>`config_template`

Data type: `String`

Template used for singularity.conf

Default value: `'singularity/singularity.conf.erb'`

##### <a name="allow_setuid"></a>`allow_setuid`

Data type: `Enum['yes','no']`

See singularity.conf: `allow setuid`

Default value: `'yes'`

##### <a name="max_loop_devices"></a>`max_loop_devices`

Data type: `Integer`

See singularity.conf: `max loop devices`

Default value: `256`

##### <a name="allow_pid_ns"></a>`allow_pid_ns`

Data type: `Enum['yes','no']`

See singularity.conf: `allow pid ns`

Default value: `'yes'`

##### <a name="config_passwd"></a>`config_passwd`

Data type: `Enum['yes','no']`

See singularity.conf: `config passwd`

Default value: `'yes'`

##### <a name="config_group"></a>`config_group`

Data type: `Enum['yes','no']`

See singularity.conf: `config group`

Default value: `'yes'`

##### <a name="config_resolv_conf"></a>`config_resolv_conf`

Data type: `Enum['yes','no']`

See singularity.conf: `config resolv conf`

Default value: `'yes'`

##### <a name="mount_proc"></a>`mount_proc`

Data type: `Enum['yes','no']`

See singularity.conf: `mount proc`

Default value: `'yes'`

##### <a name="mount_sys"></a>`mount_sys`

Data type: `Enum['yes','no']`

See singularity.conf: `mount sys`

Default value: `'yes'`

##### <a name="mount_dev"></a>`mount_dev`

Data type: `Enum['yes','no']`

See singularity.conf: `mount dev`

Default value: `'yes'`

##### <a name="mount_devpts"></a>`mount_devpts`

Data type: `Enum['yes','no']`

See singularity.conf: `mount devpts`

Default value: `'yes'`

##### <a name="mount_home"></a>`mount_home`

Data type: `Enum['yes','no']`

See singularity.conf: `mount home`

Default value: `'yes'`

##### <a name="mount_tmp"></a>`mount_tmp`

Data type: `Enum['yes','no']`

See singularity.conf: `mount tmp`

Default value: `'yes'`

##### <a name="mount_hostfs"></a>`mount_hostfs`

Data type: `Enum['yes','no']`

See singularity.conf: `mount hostfs`

Default value: `'no'`

##### <a name="bind_paths"></a>`bind_paths`

Data type: `Array[Stdlib::Absolutepath]`

See singularity.conf: `bind paths`

Default value: `['/etc/localtime', '/etc/hosts']`

##### <a name="user_bind_control"></a>`user_bind_control`

Data type: `Enum['yes','no']`

See singularity.conf: `user bind control`

Default value: `'yes'`

##### <a name="enable_fusemount"></a>`enable_fusemount`

Data type: `Enum['yes','no']`

See singularity.conf: `enable fusemount`

Default value: `'yes'`

##### <a name="enable_overlay"></a>`enable_overlay`

Data type: `Enum['yes','no','try']`

See singularity.conf: `enable overlay`

Default value: `'try'`

##### <a name="enable_underlay"></a>`enable_underlay`

Data type: `Enum['yes','no','try','driver']`

See singularity.conf: `enable underlay`

Default value: `'yes'`

##### <a name="mount_slave"></a>`mount_slave`

Data type: `Enum['yes','no']`

See singularity.conf: `mount slave`

Default value: `'yes'`

##### <a name="sessiondir_max_size"></a>`sessiondir_max_size`

Data type: `Integer`

See singularity.conf: `sessiondir max size`

Default value: `16`

##### <a name="limit_container_owners"></a>`limit_container_owners`

Data type: `Optional[Array]`

See singularity.conf: `limit container owners`

Default value: ``undef``

##### <a name="limit_container_groups"></a>`limit_container_groups`

Data type: `Optional[Array]`

See singularity.conf: `limit container groups`

Default value: ``undef``

##### <a name="limit_container_paths"></a>`limit_container_paths`

Data type: `Optional[Array]`

See singularity.conf: `limit container paths`

Default value: ``undef``

##### <a name="allow_containers"></a>`allow_containers`

Data type: `Hash[String,Enum['yes','no']]`

See singularity.conf: `allow containers`

Default value: `{
    'squashfs' => 'yes',
    'extfs' => 'yes',
    'dir' => 'yes',
    'encrypted' => 'yes',
  }`

##### <a name="allow_net_users"></a>`allow_net_users`

Data type: `Array`

See singularity.conf: `allow net users`

Default value: `[]`

##### <a name="allow_net_groups"></a>`allow_net_groups`

Data type: `Array`

See singularity.conf: `allow net groups`

Default value: `[]`

##### <a name="allow_net_networks"></a>`allow_net_networks`

Data type: `Array`

See singularity.conf: `allow net networks`

Default value: `[]`

##### <a name="always_use_nv"></a>`always_use_nv`

Data type: `Enum['yes','no']`

See singularity.conf: `always use nv`

Default value: `'no'`

##### <a name="always_use_rocm"></a>`always_use_rocm`

Data type: `Enum['yes','no']`

See singularity.conf: `always use rocm`

Default value: `'no'`

##### <a name="root_default_capabilities"></a>`root_default_capabilities`

Data type: `Enum['full','file','default','no']`

See singularity.conf: `root default capabilities`

Default value: `'full'`

##### <a name="memory_fs_type"></a>`memory_fs_type`

Data type: `Enum['tmpfs','ramfs']`

See singularity.conf: `memory fs type`

Default value: `'tmpfs'`

##### <a name="cni_configuration_path"></a>`cni_configuration_path`

Data type: `Optional[Stdlib::Absolutepath]`

See singularity.conf: `cni configuration path`

Default value: ``undef``

##### <a name="cni_plugin_path"></a>`cni_plugin_path`

Data type: `Optional[Stdlib::Absolutepath]`

See singularity.conf: `cni plugin path`

Default value: ``undef``

##### <a name="mksquashfs_path"></a>`mksquashfs_path`

Data type: `Optional[Stdlib::Absolutepath]`

See singularity.conf: `mksquashfs path`

Default value: ``undef``

##### <a name="mksquashfs_procs"></a>`mksquashfs_procs`

Data type: `Integer[0,default]`

See singularity.conf: `mksquashfs procs`

Default value: `0`

##### <a name="mksquashfs_mem"></a>`mksquashfs_mem`

Data type: `Optional[String[1]]`

See singularity.conf: `mksquashfs mem`

Default value: ``undef``

##### <a name="cryptsetup_path"></a>`cryptsetup_path`

Data type: `Optional[Stdlib::Absolutepath]`

See singularity.conf: `cryptsetup path`

Default value: ``undef``

##### <a name="shared_loop_devices"></a>`shared_loop_devices`

Data type: `Enum['yes','no']`

See singularity.conf: `shared loop devices`

Default value: `'no'`

##### <a name="image_driver"></a>`image_driver`

Data type: `Optional[String]`

See singularity.conf: `image driver`

Default value: ``undef``

##### <a name="namespace_users"></a>`namespace_users`

Data type: `Array`

List of uses to add to /etc/subuid and /etc/subgid to support user namespaces

Default value: `[]`

##### <a name="namespace_begin_id"></a>`namespace_begin_id`

Data type: `Integer`

The beginning ID for /etc/subuid and /etc/subgid. The value is incremented
For each user by start + namespace_id_range + 1

Default value: `65537`

##### <a name="namespace_id_range"></a>`namespace_id_range`

Data type: `Integer`

The range of UIDs/GIDs usable by a user in namespaces

Default value: `65536`

##### <a name="subid_template"></a>`subid_template`

Data type: `String`

The template to use for /etc/subuid and /etc/subgid

Default value: `'singularity/subid.erb'`

## Defined types

### <a name="singularityplugin"></a>`singularity::plugin`

Manage Singularity plugin

#### Examples

##### install log plugin

```puppet

singularity::plugin { 'github.com/sylabs/singularity/log-plugin':
  source_dir => 'examples/plugins/log-plugin',
}
```

#### Parameters

The following parameters are available in the `singularity::plugin` defined type:

* [`source_dir`](#source_dir)
* [`ensure`](#ensure)
* [`sif_name`](#sif_name)

##### <a name="source_dir"></a>`source_dir`

Data type: `Optional[String]`

The plugin source directory
This path must be relative to Singularity source directory `$singularity::install::source::source_dir`

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether to install (present) or uninstall (absent) the plugin

Default value: `'present'`

##### <a name="sif_name"></a>`sif_name`

Data type: `Optional[String]`

The name of the SIF image to use for install after the plugin is compiled.
The default is to use part after last `/` in the plugin name so
plugin `examples/plugins/log-plugin` will have SIF name of `log-plugin.sif`.

Default value: ``undef``

